@@ -1,11 +1,8 @@
-##########################################
-#
-#   internal functions
-#
-##########################################
-
+from functools import wraps
+from time import sleep
 from urllib.parse import quote, urlparse
 
+
 def _url_valid(url):
     try:
         result = urlparse(url)
@@ -14,13 +11,6 @@ def _url_valid(url):
         return False
 
 
-def _merge_dict(d1, d2):
-    d3 = d1.copy()
-    if d2:
-        d3.update(d2)
-    return d3
-
-
 def http_build_query(params, convention="%s"):
     if len(params) == 0:
         return ""
@@ -34,7 +24,8 @@ def http_build_query(params, convention="%s"):
 
         elif type(params[key]) is list:
 
-            new_params = {str(i): element for i, element in enumerate(params[key])}
+            new_params = {str(i): element for i, element
+                          in enumerate(params[key])}
 
             output += http_build_query(
                 new_params, convention % key + "[%s]")
@@ -45,4 +36,4 @@ def http_build_query(params, convention="%s"):
             key = quote(key)
             output = output + convention % key + "=" + val + "&"
 
-    return output
\ No newline at end of file
+    return output
